@@ -903,8 +903,8 @@ def visualize_fanio(fan_ins, fan_outs):
     fig1, fi_axes = plt.subplots(1, len(fan_ins)-1)
     fig2, fo_axes = plt.subplots(1, len(fan_outs))
 
-    fig1.suptitle("Actiavation Dists")
-    fig2.suptitle("Fan Out Dists")
+    fig1.suptitle("Actiavation Distributions")
+    fig2.suptitle("Fan Out Distributions")
 
     for i in range(len(fan_outs)):
 
